aboutsummaryrefslogtreecommitdiffstats
path: root/src/pcm/PcmDsdUsb.hxx
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2014-08-31 16:12:26 +0200
committerMax Kellermann <max@duempel.org>2014-08-31 16:12:26 +0200
commite5a28bfd8d07fe5ca5dee1bfb55ce414c8f7e9fc (patch)
tree304e2b5bfa829d95d2c756449f010bcc76762eac /src/pcm/PcmDsdUsb.hxx
parent6e04d66a354c02910ebd849f2233e52de8b6e3c4 (diff)
downloadmpd-e5a28bfd8d07fe5ca5dee1bfb55ce414c8f7e9fc.tar.gz
mpd-e5a28bfd8d07fe5ca5dee1bfb55ce414c8f7e9fc.tar.xz
mpd-e5a28bfd8d07fe5ca5dee1bfb55ce414c8f7e9fc.zip
output/alsa, pcm: rename "DSD over USB" to "DoP"
The standard has been renamed since the early draft that was implemented in MPD.
Diffstat (limited to '')
-rw-r--r--src/pcm/PcmDop.hxx (renamed from src/pcm/PcmDsdUsb.hxx)11
1 files changed, 5 insertions, 6 deletions
diff --git a/src/pcm/PcmDsdUsb.hxx b/src/pcm/PcmDop.hxx
index 5e05c009b..03161c456 100644
--- a/src/pcm/PcmDsdUsb.hxx
+++ b/src/pcm/PcmDop.hxx
@@ -17,8 +17,8 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
-#ifndef MPD_PCM_DSD_USB_HXX
-#define MPD_PCM_DSD_USB_HXX
+#ifndef MPD_PCM_DOP_HXX
+#define MPD_PCM_DOP_HXX
#include "check.h"
@@ -30,12 +30,11 @@ template<typename T> struct ConstBuffer;
/**
* Pack DSD 1 bit samples into (padded) 24 bit PCM samples for
* playback over USB, according to the proposed standard by
* dCS and others:
* http://www.sonore.us/DoP_openStandard_1v1.pdf
*/
ConstBuffer<uint32_t>
-pcm_dsd_to_usb(PcmBuffer &buffer, unsigned channels,
+pcm_dsd_to_dop(PcmBuffer &buffer, unsigned channels,
ConstBuffer<uint8_t> src);
#endif
@@ -30,12 +30,11 @@ template<typename T> struct ConstBuffer;
/**
* Pack DSD 1 bit samples into (padded) 24 bit PCM samples for
- * playback over USB, according to the proposed standard by
- * dCS and others:
- * http://www.sonore.us/DoP_openStandard_1v1.pdf
+ * playback over USB, according to the DoP standard:
+ * http://dsd-guide.com/dop-open-standard
*/
ConstBuffer<uint32_t>